summaryrefslogtreecommitdiffstats
path: root/perl-install/network/ethernet.pm
diff options
context:
space:
mode:
authorPascal Rigaux <pixel@mandriva.com>2002-07-04 22:25:15 +0000
committerPascal Rigaux <pixel@mandriva.com>2002-07-04 22:25:15 +0000
commit9602001c7823079a8e8ca0e737a8fe2f6c0db0d2 (patch)
tree6a4a4b5bb040972c82f8f23a7f154b7631d95591 /perl-install/network/ethernet.pm
parentb5b714420602230508f199cb392d21c4410a4f1d (diff)
downloaddrakx-backup-do-not-use-9602001c7823079a8e8ca0e737a8fe2f6c0db0d2.tar
drakx-backup-do-not-use-9602001c7823079a8e8ca0e737a8fe2f6c0db0d2.tar.gz
drakx-backup-do-not-use-9602001c7823079a8e8ca0e737a8fe2f6c0db0d2.tar.bz2
drakx-backup-do-not-use-9602001c7823079a8e8ca0e737a8fe2f6c0db0d2.tar.xz
drakx-backup-do-not-use-9602001c7823079a8e8ca0e737a8fe2f6c0db0d2.zip
adapt to new modules.pm
Diffstat (limited to 'perl-install/network/ethernet.pm')
-rw-r--r--perl-install/network/ethernet.pm6
1 files changed, 3 insertions, 3 deletions
diff --git a/perl-install/network/ethernet.pm b/perl-install/network/ethernet.pm
index 7c2afc405..e25cb7e68 100644
--- a/perl-install/network/ethernet.pm
+++ b/perl-install/network/ethernet.pm
@@ -82,7 +82,7 @@ qq(
sub conf_network_card {
my ($netc, $intf, $type, $ipadr, $netadr) = @_;
#-type =static or dhcp
- any::setup_thiskind($in, 'net', !$::expert, 1);
+ any::load_category($in, 'network/main|usb', !$::expert, 1);
my @all_cards=conf_network_card_backend($netc, $intf, $type, undef, $ipadr, $netadr);
my $interface;
@all_cards == () and $in->ask_warn('', _("No ethernet network adapter has been detected on your system.
@@ -105,7 +105,7 @@ I cannot set up this connection type.")) and return;
1;
}
#- conf_network_card_backend : configure the network cards and return the list of them, or configure one specified interface : WARNING, you have to setup the ethernet cards, by calling setup_thiskind($in, 'net', !$::expert, 1) or setup_thiskind_backend before calling this function. Basically, you call this function in 2 times.
#- input
#- $prefix
#- $netc
@@ -174,7 +174,7 @@ sub go_ethernet {
sub configureNetwork {
my ($netc, $intf, $first_time) = @_;
local $_;
- any::setup_thiskind($in, 'net', !$::expert, 1);
+ any::load_category($in, 'network/main|usb', !$::expert, 1);
my @l = detect_devices::getNet() or die _("no network card found");
my @all_cards = conf_network_card_backend ($netc, $intf, undef, undef, undef, undef);
@@ -105,7 +105,7 @@ I cannot set up this connection type.")) and return;
1;
}
-#- conf_network_card_backend : configure the network cards and return the list of them, or configure one specified interface : WARNING, you have to setup the ethernet cards, by calling setup_thiskind($in, 'net', !$::expert, 1) or setup_thiskind_backend before calling this function. Basically, you call this function in 2 times.
+#- conf_network_card_backend : configure the network cards and return the list of them, or configure one specified interface : WARNING, you have to setup the ethernet cards, by calling load_category($in, 'network/main|usb', !$::expert, 1) or load_category_backend before calling this function. Basically, you call this function in 2 times.
#- input
#- $prefix